const fs = require('fs');
const chalk = require('chalk');
const snippets = require('../scripts/snippets');

const reservedNames = [
  `header`,
  `section`,
  `article`,
  `aside`,
  `body`,
  `head`,
  `footer`,
  `nav`,
  `span`,
  `summary`,
];

function checkForReservedNames(tagName = '', reservedNames = []) {
  return reservedNames.includes(tagName.toLowerCase());
}

function generate(itemType = '', itemName = '') {
  if (itemType === `c` || itemType === `component`) {
    checkName(itemName);
  } else {
    console.log(`should not generate component`);
    process.exit(1);
  }
}

function checkName(name = '') {
  const patterns = {
    amtPrefix: new RegExp(`^(amt)+`, `gi`),
    // kebab: new RegExp(`^([a-z-]+)([a-z])*`, `g`),
    kebab: new RegExp(`[-]`, `gi`),
    uppercase: new RegExp(`[A-Z]`, `g`),
    digit: new RegExp(/\d/),
  };
  if (checkForReservedNames(name, reservedNames)) {
    console.log(
      chalk.red.underline.bold(`
       _____________________________________________________
      |                                                     |
      |        Reserved HTML names are NOT ALLOWED!         |
      |_____________________________________________________|
      `)
    );
  }
  if (patterns.digit.test(name)) {
    console.log(
      chalk.red.underline.bold(`
       _____________________________________________________
      |                                                     |
      |  Components cannot have names that contain digits!  |
      |_____________________________________________________|
      `)
    );
    process.exit(1);
  }
  if (!patterns.kebab.test(name) || patterns.uppercase.test(name)) {
    console.log(
      chalk.red.underline.bold(`
       _____________________________________________________
      |                                                     |
      |  Components MUST be kebab-case and not contain      |
      |  capital letters!                                   |
      |_____________________________________________________|
      `)
    );
    process.exit(1);
  }

  createFileStructure(itemName);
}

function createFileStructure(name = '') {
  const locationPath = `${process.cwd()}/${name.toLowerCase()}`;
  fs.mkdir(locationPath, { recursive: false }, (err) => {
    if (err) {
      if (err.code === `EEXIST`) {
        console.log(
          chalk.red.underline.bold(`
            The ${name} component already exists!
          `)
        );
      }
    }
  });
  fs.writeFile(`${locationPath}/${name}.tsx`, snippets.tsx(name), (err) => {
    if (err) console.log(err);
  });
  fs.writeFile(`${locationPath}/${name}.scss`, snippets.scss(name), (err) => {
    if (err) console.log(err);
  });
}

module.exports = generate;
