function createComponentName(componentName = '') {
  const splitNames = componentName.toLowerCase().split(`-`);
  let convertedNames = splitNames.map(name => `${name[0].toUpperCase()}${name.slice(1)}`);

  return convertedNames.join(``);
}

function getTsxSnippet(componentName = '') {
  return(`import { Component, Prop, Host, h, State, Element } from '@stencil/core';

@Component({
  tag: '${componentName}',
  styleUrls: ['./${componentName}.scss'],
  shadow: false
})
export class ${createComponentName(componentName)} {
  @Prop({ attribute: 'name', reflect: true }) name: string;
  @Element() el: HTMLElement;
  @State() klassName: string = \`${componentName}\`;

  /**
   * Lifecycle hooks in the order that they are called. Uncomment to use
  */
  // componentWillLoad() { }
  // componentDidLoad() { }
  // componentWillRender() { }
  // componentWillUpdate() { }
  // componentDidUpdate() { }

  /**
   * The render() function should always be the last one in the class
  */
  render() {
    return (
      <Host class={this.klassName}>
        <p>Welcome this is the ${createComponentName(componentName)} component</p>
      </Host>
    );
  }
}\n`
  );
}

function getScssSnippet(componentName = '') {
  const shadow = `:host {\n  // Styling for the ${componentName} host element go here\n}\n`;
  const nonShadow = `.${componentName} {\n  // Styling for the ${componentName} host element go here\n}\n`
  /**
   * TODO: Set up a switch for shadow DOM
   */
  return nonShadow;
}

module.exports = {
  tsx: getTsxSnippet,
  scss: getScssSnippet,
}

